@@ -1,6 +1,8 @@
-from dlup.data.dataset import TiledROIsSlideImageDataset, ConcatDataset
 import pathlib
 
+from dlup.data.dataset import ConcatDataset, TiledROIsSlideImageDataset
+
+
 class PMCHHGTileDataset(ConcatDataset):
     """
     add documentation on how this dataset works
@@ -9,17 +11,6 @@ class PMCHHGTileDataset(ConcatDataset):
     """
 
     def __init__(self, cfg, path, split, dataset_name, data_source):
-        #split should only be train
-        #dataset_name should be passed as 'tcga_tile_folder' - name from json
-        #dataset_source is passed as ['tile_dataset'] -name (of data source) referring to the dataset class
-
-
-        #Was used and worked for testing
-        # self.cfg = VisslDatasetCatalog.get(dataset_name)  #retrieves the dict with the paths from the catalog
-        # split = split.lower()
-        # path_images = self.cfg[split][0]
-        # path_labels = self.cfg[split][1]
-
         self.path = pathlib.Path(path)
         super().__init__([TiledROIsSlideImageDataset(fn) for fn in self.path.glob("*")])
 
@@ -36,4 +27,4 @@ class PMCHHGTileDataset(ConcatDataset):
         """
         tile_dict = ConcatDataset.__getitem__(self, idx)
 
-        return tile_dict["image"]
\ No newline at end of file
+        return tile_dict["image"]
